<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Mega Blog Pro
 * @since Mega Blog Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'mega_blog_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery Slides','mega-blog-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'mega-blog-pro' ),
	'panel'             => 'mega_blog_pro_front_page_panel',
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Blog_Pro_Switch_Control( $wp_customize, 'mega_blog_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_gallery_section',
	'on_off_label' 		=> mega_blog_pro_switch_options(),
) ) );

// Gallery title setting and control
$wp_customize->add_setting( 'mega_blog_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[gallery_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-blog-pro' ),
	'section'        	=> 'mega_blog_pro_gallery_section',
	'active_callback' 	=> 'mega_blog_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_blog_pro_theme_options[gallery_title]', array(
		'selector'            => '#gallery-posts .wrapper h2.section-title',
		'settings'            => 'mega_blog_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_blog_pro_gallery_title_partial',
    ) );
}

// Gallery alignment control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[gallery_alignment]', array(
	'default'          	=> $options['gallery_alignment'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[gallery_alignment]', array(
	'label'             => esc_html__( 'Slider Alignment', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_gallery_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'mega_blog_pro_is_gallery_section_enable',
	'choices'			=> array( 
		'left-align' 	=> esc_html__( 'Left', 'mega-blog-pro' ),
		'right-align' 	=> esc_html__( 'Right', 'mega-blog-pro' ),
	),
) );

// Gallery content type control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_blog_pro_is_gallery_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-blog-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-blog-pro' ),
		'category' 	=> esc_html__( 'Category', 'mega-blog-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[gallery_count]', array(
	'default'          	=> $options['gallery_count'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_number_range',
	'validate_callback' => 'mega_blog_pro_validate_gallery_count',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[gallery_count]', array(
	'label'             => esc_html__( 'Number of Recent Posts', 'mega-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_gallery_section',
	'active_callback'   => 'mega_blog_pro_is_gallery_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :
	// gallery pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_blog_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Chooser( $wp_customize, 'mega_blog_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-blog-pro' ), $i ),
		'section'           => 'mega_blog_pro_gallery_section',
		'choices'			=> mega_blog_pro_page_choices(),
		'active_callback'	=> 'mega_blog_pro_is_gallery_section_content_page_enable',
	) ) );

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_blog_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Chooser( $wp_customize, 'mega_blog_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-blog-pro' ), $i ),
		'section'           => 'mega_blog_pro_gallery_section',
		'choices'			=> mega_blog_pro_post_choices(),
		'active_callback'	=> 'mega_blog_pro_is_gallery_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_blog_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'mega_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_blog_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_blog_pro_is_gallery_section_content_category_enable'
) ) );
