<?php
/**
 * Message Section options
 *
 * @package Theme Palace
 * @subpackage Mega Blog Pro
 * @since Mega Blog Pro 1.0.0
 */

// Add Message section
$wp_customize->add_section( 'mega_blog_pro_message_section', array(
	'title'             => esc_html__( 'Author&#39;s Message','mega-blog-pro' ),
	'description'       => esc_html__( 'Message Section options.', 'mega-blog-pro' ),
	'panel'             => 'mega_blog_pro_front_page_panel',
) );

// Message content enable control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[message_section_enable]', array(
	'default'			=> 	$options['message_section_enable'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Blog_Pro_Switch_Control( $wp_customize, 'mega_blog_pro_theme_options[message_section_enable]', array(
	'label'             => esc_html__( 'Message Section Enable', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_message_section',
	'on_off_label' 		=> mega_blog_pro_switch_options(),
) ) );

// Message us content type control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[message_content_type]', array(
	'default'          	=> $options['message_content_type'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[message_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_message_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_blog_pro_is_message_section_enable',
	'choices'			=> array( 
		'custom' 	=> esc_html__( 'Custom', 'mega-blog-pro' ),
		'page' 		=> esc_html__( 'Page', 'mega-blog-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-blog-pro' ),
	),
) );

// message pages drop down chooser control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[message_content_page]', array(
	'sanitize_callback' => 'mega_blog_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Chooser( $wp_customize, 'mega_blog_pro_theme_options[message_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_message_section',
	'choices'			=> mega_blog_pro_page_choices(),
	'active_callback'	=> 'mega_blog_pro_is_message_section_content_page_enable',
) ) );

// message posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[message_content_post]', array(
	'sanitize_callback' => 'mega_blog_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Blog_Pro_Dropdown_Chooser( $wp_customize, 'mega_blog_pro_theme_options[message_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_message_section',
	'choices'			=> mega_blog_pro_post_choices(),
	'active_callback'	=> 'mega_blog_pro_is_message_section_content_post_enable',
) ) );

// Message us title setting and control
$wp_customize->add_setting( 'mega_blog_pro_theme_options[message_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['message_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[message_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-blog-pro' ),
	'section'        	=> 'mega_blog_pro_message_section',
	'active_callback' 	=> 'mega_blog_pro_is_message_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_blog_pro_theme_options[message_title]', array(
		'selector'            => '#message-from-author .wrapper .entry-header h2.entry-title',
		'settings'            => 'mega_blog_pro_theme_options[message_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_blog_pro_message_title_partial',
    ) );
}

// Message us description setting and control
$wp_customize->add_setting( 'mega_blog_pro_theme_options[message_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'          	=> $options['message_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_blog_pro_theme_options[message_description]', array(
	'label'           	=> esc_html__( 'Description', 'mega-blog-pro' ),
	'section'        	=> 'mega_blog_pro_message_section',
	'active_callback' 	=> 'mega_blog_pro_is_message_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_blog_pro_theme_options[message_description]', array(
		'selector'            => '#message-from-author .wrapper .entry-content',
		'settings'            => 'mega_blog_pro_theme_options[message_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_blog_pro_message_description_partial',
    ) );
}

// message Section background setting and control.
$wp_customize->add_setting( 'mega_blog_pro_theme_options[message_image]', array(
	'default'           => $options['message_image'],
	'sanitize_callback' => 'mega_blog_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'mega_blog_pro_theme_options[message_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'mega-blog-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-blog-pro' ), 200, 200 ),
		'section'     		=> 'mega_blog_pro_message_section',
		'active_callback'	=> 'mega_blog_pro_is_message_section_content_custom_enable',
) ) );

// Author social icons control and setting
$wp_customize->add_setting( 'mega_blog_pro_theme_options[message_social]', array(
	'sanitize_callback' => 'mega_blog_pro_sanitize_links',
	'default'			=> $options['message_social'],
) );

$wp_customize->add_control( new Mega_Blog_Pro_Multi_Input_Custom_Control( $wp_customize, 'mega_blog_pro_theme_options[message_social]', array(
	'label'             => esc_html__( 'Social Links', 'mega-blog-pro' ),
	'button_text'       => esc_html__( 'Add Social Link', 'mega-blog-pro' ),
	'section'           => 'mega_blog_pro_message_section',
	'active_callback' 	=> 'mega_blog_pro_is_message_section_enable',
) ) );